#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include "IOTCClient.h"
#include "sample_constants.h"

#define CHECK_DEVICE_MS 5000
int main(int argc, char **argv) {
    if (argc < 2) {
        printf("Usage: %s UID [AUTH_KEY]\n", argv[0]);
        return -1;
    }
    char *UID = argv[1];

    const char *license_key = getenv(ENV_LICENSE_KEY);
    if (license_key == NULL) {
        printf("Environment variable %s must be set!!\n", ENV_LICENSE_KEY);
        return -1;
    }

    IOTCCheckDeviceInput* input = NULL;
    if (argc > 2) {
		if (strlen(argv[2]) != IOTC_AUTH_KEY_LENGTH) {
            printf("Invalid key length expect:%d actual:%lu\n", IOTC_AUTH_KEY_LENGTH, strlen(argv[2]));
            return -1;
        }

        input = calloc(1, sizeof(IOTCCheckDeviceInput));
        input->cb = sizeof(IOTCCheckDeviceInput);
        strncpy(input->auth_key, argv[2], IOTC_AUTH_KEY_LENGTH);
        input->authentication_type = AUTHENTICATE_BY_KEY;
        printf("Check device with key=%s\n", argv[2]);
    }

    int ret = TUTK_SDK_Set_License_Key(license_key);
    if (ret < 0) {
        printf("TUTK_SDK_Set_License_Key fail %d!!\n", ret);
        return -1;
    }

    ret = IOTC_Initialize2(0);
	if (ret < 0) {
        printf("IOTC_Initialize2 fail: %d!!\n", ret);
		return -1;
    }

    IOTCCheckDeviceOutput output;
    ret = IOTC_Check_Device_OnlineEx(UID, input, &output, CHECK_DEVICE_MS, NULL);
    if (ret == IOTC_ER_NoERROR) {
        char* status = (output.Status & 0x01) == 1 ? "sleeping" : "online";
        time_t lastlogin = output.LastLoginTimestamp;
        struct tm tm;
        gmtime_r(&lastlogin, &tm);
        char timestring[50];
        strftime(timestring, sizeof(timestring), "[%y-%m-%d %H:%M:%S]", &tm);
        printf("Device report %s at %s\n", status , timestring);
    } else if (ret == IOTC_ER_DEVICE_OFFLINE) {
        printf("Device offline\n");
    } else if (ret == IOTC_ER_SERVER_NOT_SUPPORT) {
        printf("P2P Server does not support this feature\n");
    } else {
        printf("IOTC_Check_Device_OnlineEx fails: %d!!\n", ret);
    }

    IOTC_DeInitialize();
    return 0;
}
